mocks

package
v0.0.0-...-e97be17 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 21, 2022 License: MIT Imports: 7 Imported by: 0

Documentation

Overview

Package mocks is a generated GoMock package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockIndexerClient

type MockIndexerClient struct {
	// contains filtered or unexported fields
}

MockIndexerClient is a mock of IndexerClient interface.

func NewMockIndexerClient

func NewMockIndexerClient(ctrl *gomock.Controller) *MockIndexerClient

NewMockIndexerClient creates a new mock instance.

func (*MockIndexerClient) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockIndexerClient) Index

func (m *MockIndexerClient) Index(arg0 context.Context, arg1 *proto.Document, arg2 ...grpc.CallOption) (*proto.Document, error)

Index mocks base method.

func (*MockIndexerClient) Search

Search mocks base method.

func (*MockIndexerClient) UpdateScore

func (m *MockIndexerClient) UpdateScore(arg0 context.Context, arg1 *proto.UpdateScoreRequest, arg2 ...grpc.CallOption) (*emptypb.Empty, error)

UpdateScore mocks base method.

type MockIndexerClientMockRecorder

type MockIndexerClientMockRecorder struct {
	// contains filtered or unexported fields
}

MockIndexerClientMockRecorder is the mock recorder for MockIndexerClient.

func (*MockIndexerClientMockRecorder) Index

func (mr *MockIndexerClientMockRecorder) Index(arg0, arg1 interface{}, arg2 ...interface{}) *gomock.Call

Index indicates an expected call of Index.

func (*MockIndexerClientMockRecorder) Search

func (mr *MockIndexerClientMockRecorder) Search(arg0, arg1 interface{}, arg2 ...interface{}) *gomock.Call

Search indicates an expected call of Search.

func (*MockIndexerClientMockRecorder) UpdateScore

func (mr *MockIndexerClientMockRecorder) UpdateScore(arg0, arg1 interface{}, arg2 ...interface{}) *gomock.Call

UpdateScore indicates an expected call of UpdateScore.

type MockIndexer_SearchClient

type MockIndexer_SearchClient struct {
	// contains filtered or unexported fields
}

MockIndexer_SearchClient is a mock of Indexer_SearchClient interface.

func NewMockIndexer_SearchClient

func NewMockIndexer_SearchClient(ctrl *gomock.Controller) *MockIndexer_SearchClient

NewMockIndexer_SearchClient creates a new mock instance.

func (*MockIndexer_SearchClient) CloseSend

func (m *MockIndexer_SearchClient) CloseSend() error

CloseSend mocks base method.

func (*MockIndexer_SearchClient) Context

Context mocks base method.

func (*MockIndexer_SearchClient) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockIndexer_SearchClient) Header

func (m *MockIndexer_SearchClient) Header() (metadata.MD, error)

Header mocks base method.

func (*MockIndexer_SearchClient) Recv

Recv mocks base method.

func (*MockIndexer_SearchClient) RecvMsg

func (m *MockIndexer_SearchClient) RecvMsg(arg0 interface{}) error

RecvMsg mocks base method.

func (*MockIndexer_SearchClient) SendMsg

func (m *MockIndexer_SearchClient) SendMsg(arg0 interface{}) error

SendMsg mocks base method.

func (*MockIndexer_SearchClient) Trailer

func (m *MockIndexer_SearchClient) Trailer() metadata.MD

Trailer mocks base method.

type MockIndexer_SearchClientMockRecorder

type MockIndexer_SearchClientMockRecorder struct {
	// contains filtered or unexported fields
}

MockIndexer_SearchClientMockRecorder is the mock recorder for MockIndexer_SearchClient.

func (*MockIndexer_SearchClientMockRecorder) CloseSend

CloseSend indicates an expected call of CloseSend.

func (*MockIndexer_SearchClientMockRecorder) Context

Context indicates an expected call of Context.

func (*MockIndexer_SearchClientMockRecorder) Header

Header indicates an expected call of Header.

func (*MockIndexer_SearchClientMockRecorder) Recv

Recv indicates an expected call of Recv.

func (*MockIndexer_SearchClientMockRecorder) RecvMsg

func (mr *MockIndexer_SearchClientMockRecorder) RecvMsg(arg0 interface{}) *gomock.Call

RecvMsg indicates an expected call of RecvMsg.

func (*MockIndexer_SearchClientMockRecorder) SendMsg

func (mr *MockIndexer_SearchClientMockRecorder) SendMsg(arg0 interface{}) *gomock.Call

SendMsg indicates an expected call of SendMsg.

func (*MockIndexer_SearchClientMockRecorder) Trailer

Trailer indicates an expected call of Trailer.

Jump to