Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
GraphAPI GraphAPI
IndexAPI IndexAPI
// An API for detecting the partition assignments for this service.
PartitionDetector partition.Detector
// A clock instance for generating time-related events. If not specified,
// the default wall-clock will be used instead.
Clock clock.Clock
// The number of workers to spin up for computing PageRank scores. If
// not specified, a default value of 1 will be used instead.
ComputeWorkers int
// The time between subsequent crawler passes.
UpdateInterval time.Duration
Logger *logrus.Entry
}
Config encapsulates the settings for configuring the ranker service.
type Service ¶
type Service struct {
// contains filtered or unexported fields
}
Service implements the ranker component for the Links 'R' Us project.
func NewService ¶
NewService creates a new Ranker service instance with the specified config.
Click to show internal directories.
Click to hide internal directories.