Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // ErrNotFound is returned by the indexer when attempting to look up // a document that does not exist. ErrNotFound = xerrors.New("not found") // ErrMissingLinkID is returned when attempting to index a document // that does not specify a valid link ID. ErrMissingLinkID = xerrors.New("document does not provide a valid linkID") )
Functions ¶
This section is empty.
Types ¶
type Document ¶
type Document struct {
LinkID uuid.UUID
URL string
// The Title and Content attributes correspond to the value of the <title> element
// if the link points to an HTML page, whereas the Content attribute stores
// the block of text that was extracted by the crawler when processing the link.
Title string
Content string
// indicates when a particular document was last indexed
IndexedAt time.Time
// track the score that will be assigned to each document by the PageRank calculator component
PageRank float64
}
Click to show internal directories.
Click to hide internal directories.