Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DynamicWorkerPool ¶
func DynamicWorkerPool(proc pipeline.Processor, maxWorkers int) pipeline.StageRunner
DynamicWorkerPool returns a StageRunner that implemets a dynamic worker pool that can scale up to maxWorkers for processing incomming payloads concurrently
func FIFO ¶
func FIFO(proc pipeline.Processor) pipeline.StageRunner
FIFO returns a StageRunner that process payloads in first-in-first-out fashion. Input passed to the specified processor and output to the next stage.
func FixedWorkerPool ¶
func FixedWorkerPool(proc pipeline.Processor, numWorkers int) pipeline.StageRunner
StaticWorkerPool returns a StageRunner that starts a pool of numWorkers to process incoming payload in parallel.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.