Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ServiceGroup ¶
type ServiceGroup []Service
func (ServiceGroup) Run ¶
func (g ServiceGroup) Run(ctx context.Context) error
Run executes all Service instances in the group using the provided context. Calls to Run block until all services have completed executing either because the context was cancelled or any of the services reported an error.
Directories
¶
| Path | Synopsis |
|---|---|
|
mocks
Package mocks is a generated GoMock package.
|
Package mocks is a generated GoMock package. |
|
mocks
Package mocks is a generated GoMock package.
|
Package mocks is a generated GoMock package. |
|
mocks
Package mocks is a generated GoMock package.
|
Package mocks is a generated GoMock package. |
Click to show internal directories.
Click to hide internal directories.